@@ -326,6 +326,8 @@ class TextComp(Component):
         super().__init__(json_data)
         self.font_url = json_data['font_url']
         self.font_size = json_data['fontSize']
+        #fontsize px need to convert to pt
+        self.font_size = int(math.ceil(float(self.font_size)*3.0/4.0))
         self.bg_color = json_data['backgroundColor']
         if self.bg_color is None or self.bg_color == "":
             self.bg_color="transparent"
